@@ -7,12 +7,12 @@
 ## ----style, echo = FALSE, results = 'asis'-------------------------------
 BiocStyle::markdown()
 
-## ----eval=FALSE,message=FALSE--------------------------------------------
-#  library(MLML2R)
-#  library(minfi)
-#  library(GEOquery)
+## ----packages,eval=TRUE,message=FALSE------------------------------------
+library(MLML2R)
+library(minfi)
+library(GEOquery)
 
-## ----eval=FALSE----------------------------------------------------------
+## ----getData1,eval=FALSE-------------------------------------------------
 #  getGEOSuppFiles("GSE63179")
 #  untar("GSE63179/GSE63179_RAW.tar", exdir = "GSE63179/idat")
 #  
@@ -20,18 +20,25 @@ BiocStyle::markdown()
 #  files <- list.files("GSE63179/idat", pattern = "idat.gz$", full = TRUE)
 #  sapply(files, gunzip, overwrite = TRUE)
 
-## ----eval=FALSE----------------------------------------------------------
+## ----readData1,eval=FALSE------------------------------------------------
 #  rgSet <- read.metharray.exp("GSE63179/idat")
 
-## ----eval=FALSE,echo=FALSE-----------------------------------------------
-#  rgSet <- read.metharray.exp("../data-raw/example1/GSE63179/idat")
-
 ## ----eval=FALSE----------------------------------------------------------
 #  pData(rgSet)
 
-## ----eval=FALSE----------------------------------------------------------
-#  geoMat <- getGEO("GSE63179")
-#  pD.all <- pData(geoMat[[1]])
+## ----getPheno1,eval=FALSE------------------------------------------------
+#  if (!file.exists("GSE63179/GSE63179_series_matrix.txt.gz"))
+#  download.file(
+#    "https://ftp.ncbi.nlm.nih.gov/geo/series/GSE63nnn/GSE63179/matrix/GSE63179_series_matrix.txt.gz",
+#    "GSE63179/GSE63179_series_matrix.txt.gz")
+#  
+#  geoMat <- getGEO(filename="GSE63179/GSE63179_series_matrix.txt.gz",getGPL=FALSE)
+#  pD.all <- pData(geoMat)
+#  
+#  #Another option
+#  #geoMat <- getGEO("GSE63179")
+#  #pD.all <- pData(geoMat[[1]])
+#  
 #  pD <- pD.all[, c("title", "geo_accession", "characteristics_ch1.1",
 #                   "characteristics_ch1.2","characteristics_ch1.3")]
 #  pD
@@ -44,7 +51,7 @@ BiocStyle::markdown()
 #  pData(rgSet) <- as(pD,"DataFrame")
 #  rgSet
 
-## ----eval=FALSE----------------------------------------------------------
+## ----Preprocess1,eval=FALSE----------------------------------------------
 #  MSet.noob<- preprocessNoob(rgSet)
 
 ## ----eval=FALSE----------------------------------------------------------
@@ -53,11 +60,11 @@ BiocStyle::markdown()
 #  MethylatedOxBS <- getMeth(MSet.noob)[,c(7,8,2,4)]
 #  UnMethylatedOxBS <- getUnmeth(MSet.noob)[,c(7,8,2,4)]
 
-## ----eval=FALSE----------------------------------------------------------
+## ----MLML2Rexact1,eval=FALSE---------------------------------------------
 #  results_exact <- MLML(T.matrix = MethylatedBS , U.matrix = UnMethylatedBS,
 #                        L.matrix = UnMethylatedOxBS, M.matrix = MethylatedOxBS)
 
-## ----eval=FALSE----------------------------------------------------------
+## ----MLML2REM1,eval=FALSE------------------------------------------------
 #  results_em <- MLML(T.matrix = MethylatedBS , U.matrix = UnMethylatedBS,
 #                     L.matrix = UnMethylatedOxBS, M.matrix = MethylatedOxBS,
 #                     iterative = TRUE)
@@ -65,9 +72,6 @@ BiocStyle::markdown()
 ## ----echo=TRUE,eval=FALSE------------------------------------------------
 #  all.equal(results_exact$hmC,results_em$hmC,scale=1)
 
-## ----echo=FALSE,eval=FALSE-----------------------------------------------
-#  load("../data-raw/example1/results_exact.rds")
-
 ## ----plot,echo=FALSE,eval=FALSE------------------------------------------
 #  pdf(file="Real1_estimates.pdf",width=15,height=5)
 #  par(mfrow =c(1,3))
@@ -79,11 +83,78 @@ BiocStyle::markdown()
 ## ----echo=FALSE,fig.width=15,fig.height=5,fig.cap="Estimated proportions of hydroxymethylation, methylation and unmethylation for the CpGs in the dataset using the MLML function with default options."----
 knitr::include_graphics("Real1_estimates.pdf") 
 
-## ----echo=FALSE,eval=FALSE-----------------------------------------------
-#  load("../data-raw/example1/results_exact.rds")
-#  load("../data-raw/Input.rds")
+## ----getData2,eval=FALSE-------------------------------------------------
+#  getGEOSuppFiles("GSE71398")
+#  untar("GSE71398/GSE71398_RAW.tar", exdir = "GSE71398/idat")
+#  
+#  list.files("GSE71398/idat", pattern = "idat")
+#  files <- list.files("GSE71398/idat", pattern = "idat.gz$", full = TRUE)
+#  sapply(files, gunzip, overwrite = TRUE)
+
+## ----readData2,eval=FALSE------------------------------------------------
+#  rgSet <- read.metharray.exp("GSE71398/idat")
+
+## ----eval=FALSE----------------------------------------------------------
+#  pData(rgSet)
+
+## ----getPheno2,eval=FALSE------------------------------------------------
+#  if (!file.exists("GSE71398/GSE71398_series_matrix.txt.gz"))
+#  download.file(
+#    "https://ftp.ncbi.nlm.nih.gov/geo/series/GSE71nnn/GSE71398/matrix/GSE71398_series_matrix.txt.gz",
+#    "GSE71398/GSE71398_series_matrix.txt.gz")
+#  
+#  geoMat <- getGEO(filename="GSE71398/GSE71398_series_matrix.txt.gz",getGPL=FALSE)
+#  pD.all <- pData(geoMat)
+#  pD <- pD.all[, c("title", "geo_accession", "source_name_ch1")]
+#  pD$method <- sapply(pD$source_name_ch1,function(x) strsplit(as.character(x),",")[[1]][3])
+#  pD$group <- sapply(pD$source_name_ch1,function(x) strsplit(as.character(x),",")[[1]][2])
+#  pD$sample <- as.numeric(substr(as.character(pD$title),start=7,stop=8))
+
+## ----eval=FALSE----------------------------------------------------------
+#  sampleNames(rgSet) <- sapply(sampleNames(rgSet),function(x)   strsplit(x,"_")[[1]][1])
+#  rownames(pD) <- as.character(pD$geo_accession)
+#  pD <- pD[sampleNames(rgSet),]
+#  pData(rgSet) <- as(pD,"DataFrame")
+#  rgSet
+
+## ----preprocess2,eval=FALSE----------------------------------------------
+#  MSet.noob<- preprocessNoob(rgSet)
+
+## ----eval=FALSE----------------------------------------------------------
+#  BSindex <- which(pD$method == " BS-chip")
+#  TABindex <- which(pD$method == " TAB-chip")
+#  MethylatedBS <- getMeth(MSet.noob)[,BSindex]
+#  UnMethylatedBS <- getUnmeth(MSet.noob)[,BSindex]
+#  MethylatedTAB <- getMeth(MSet.noob)[,TABindex]
+#  UnMethylatedTAB <- getUnmeth(MSet.noob)[,TABindex]
+
+## ----eval=FALSE----------------------------------------------------------
+#  results_exact <- MLML(T.matrix = MethylatedBS , U.matrix = UnMethylatedBS,
+#                        G.matrix = UnMethylatedTAB, H.matrix = MethylatedTAB)
+
+## ----MLML2REM2,eval=FALSE------------------------------------------------
+#  results_em <- MLML(T.matrix = MethylatedBS , U.matrix = UnMethylatedBS,
+#                     G.matrix = UnMethylatedTAB, H.matrix = MethylatedTAB,
+#                     iterative = TRUE)
 
 ## ----echo=TRUE,eval=FALSE------------------------------------------------
+#  all.equal(results_exact$hmC,results_em$hmC,scale=1)
+
+## ----echo=TRUE,eval=FALSE------------------------------------------------
+#  all.equal(results_exact$mC,results_em$mC,scale=1)
+
+## ----plot3,echo=FALSE,eval=FALSE-----------------------------------------
+#  pdf(file="Real2_estimates.pdf",width=15,height=5)
+#  par(mfrow =c(1,3))
+#  densityPlot(results_exact$hmC,main= "5-hmC using PAVA",cex.axis=1.4,cex.main=1.5,cex.lab=1.4,xlab="Proportion",sampGroups=pD$group)
+#  densityPlot(results_exact$mC,main= "5-mC using PAVA",cex.axis=1.4,cex.main=1.5,cex.lab=1.4,xlab="Proportion",sampGroups=pD$group)
+#  densityPlot(results_exact$C,main= "5-C using PAVA",cex.axis=1.4,cex.main=1.5,cex.lab=1.4,xlab="Proportion",sampGroups=pD$group)
+#  dev.off()
+
+## ----echo=FALSE,fig.width=15,fig.height=5,fig.cap="Estimated proportions of hydroxymethylation, methylation and unmethylation for the CpGs in the dataset using the MLML function with default options."----
+knitr::include_graphics("Real2_estimates.pdf") 
+
+## ----simulation,echo=TRUE,eval=FALSE-------------------------------------
 #  set.seed(112017)
 #  
 #  index <- sample(1:dim(results_exact$mC)[1],1000,replace=FALSE) # 1000 CpGs
@@ -100,6 +171,7 @@ knitr::include_graphics("Real1_estimates.pdf")
 #    MethylatedBS_temp[i] <- rbinom(n=1, size=temp1$n[i], prob=(temp1$p_m[i]+temp1$p_h[i]))
 #  }
 #  
+#  
 #  UnMethylatedBS_sim2 <- matrix(Coverage - MethylatedBS_temp,ncol=2)
 #  MethylatedBS_sim2 <- matrix(MethylatedBS_temp,ncol=2)
 #  
@@ -241,7 +313,7 @@ G.matrix = UnMethylatedTAB_sim2, H.matrix = MethylatedTAB_sim2)
 ## ------------------------------------------------------------------------
  all.equal(results_emBOT1$hmC,results_exactBOT1$hmC,scale=1)
 
-## ------------------------------------------------------------------------
+## ----computationCost-----------------------------------------------------
  mbmBOT1 = microbenchmark(
     EXACT = MLML(T.matrix = MethylatedBS_sim2, U.matrix = UnMethylatedBS_sim2,
                  L.matrix = UnMethylatedOxBS_sim2, M.matrix = MethylatedOxBS_sim2,
